from setuptools import setup

setup(name='probab_dsnd',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['probab_dsnd'],
      author = 'Sabin Adhikari',
      author_email = 'adhikarisabin258@gmail.com',
      zip_safe=False)
